# coding: utf-8

from django.contrib.contenttypes.models import ContentType
from django.core.exceptions import ValidationError
from django.core.validators import EmailValidator
from django.utils.translation import pgettext_lazy as _

from email_confirm_la.models import EmailConfirmation


class AuthUserEmailValidator(EmailValidator):

    def __call__(self, value):
        super(AuthUserEmailValidator, self).__call__(value)

        from django.contrib.auth.models import User

        if User.objects.filter(email__iexact=value).exists():
            raise ValidationError(_('ecla', 'This email has already been taken.'))


class EmailConfirmationValidator(EmailValidator):

    def __init__(self, content_object_model, email_field_name='email', regex=None, message=None, code=None):
        super(EmailConfirmationValidator, self).__init__(regex, message, code)

        self.content_type = ContentType.objects.get_for_model(content_object_model)
        self.email_field_name = email_field_name

    def __call__(self, value):
        super(EmailConfirmationValidator, self).__call__(value)

        email_exists = EmailConfirmation.objects \
            .filter(content_type=self.content_type, email_field_name=self.email_field_name) \
            .filter(email__iexact=value) \
            .exists()
        if email_exists:
            raise ValidationError(_('ecla', 'This email has already been taken.'))



# coding: utf-8

from django.contrib.auth.models import User
from django.core import mail
from django.test.utils import override_settings

from .base import BaseTestCase
from email_confirm_la.models import EmailConfirmation


class ViewTest(BaseTestCase):

    def setUp(self):
        self.user_obj = User.objects.create_user(username='kiko_mizuhara')
        self.user_email = 'kiko.mizuhara@gmail.com'
        self.user_email_2 = 'kiko.mizuhara@yahoo.com'

    def test_confirm_email(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)
        self.assertEqual(response.status_code, 200)

        self.user_obj = User.objects.get(id=self.user_obj.id)
        self.assertEqual(self.user_obj.email, self.user_email)

    def test_confirm_email_invalid(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        confirmation.confirmation_key = 'broken'

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)

        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(
            response,
            'email_confirm_la/email_confirmation_fail.html'
        )

    @override_settings(EMAIL_CONFIRM_LA_HTTP_PROTOCOL='https', EMAIL_CONFIRM_LA_DOMAIN='vinta.ws')
    def test_custom_domain(self):
        EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        mail_obj = mail.outbox[0]

        self.assertIn('https://vinta.ws/', mail_obj.body)

    @override_settings(EMAIL_CONFIRM_LA_CONFIRM_URL_REVERSE_NAME='test_app:your_confirm_email')
    def test_custom_confirm_url_reverse_name(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)

        self.assertIn('/test_app/your_confirm_email/', url)

        response = self.client.get(url)

        self.assertEqual(response.status_code, 200)

        confirmation = EmailConfirmation.objects.get(id=confirmation.id)
        self.user_obj = User.objects.get(id=self.user_obj.id)

        self.assertEqual(self.user_obj.email, self.user_email)

    @override_settings(EMAIL_CONFIRM_LA_CONFIRM_URL_REVERSE_NAME='test_app:your_confirm_email')
    def test_custom_template_context_in_email(self):
        EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        mail_obj = mail.outbox[0]

        self.assertIn('the Answer to the Ultimate Question of Life, the Universe, and Everything: 42.', mail_obj.body)

    def test_custom_template_context_in_view(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        url = confirmation.get_confirmation_url(full=False)
        response = self.client.get(url)

        self.assertContains(response, 'the Answer to the Ultimate Question of Life, the Universe, and Everything: 42.')



# coding: utf-8

from django.contrib.admin import ModelAdmin
from django.contrib.admin.sites import AdminSite

from model_mommy import mommy

from .base import BaseTestCase
from email_confirm_la.models import EmailConfirmation


class MockRequest(object):
    pass


class MockSuperUser(object):
    def has_perm(self, perm):
        return True


request = MockRequest()
request.user = MockSuperUser()


class AdminTest(BaseTestCase):

    def setUp(self):
        mommy.make(
            'email_confirm_la.EmailConfirmation',
            _quantity=1,
        )
        self.site = AdminSite()

    def test_confirm_email(self):
        ecla_admin = ModelAdmin(EmailConfirmation, self.site)
        ecla_form = ecla_admin.get_form(request)

        self.assertIn('email_field_name', ecla_form.base_fields.keys())
        self.assertIn('email', ecla_form.base_fields.keys())



# coding: utf-8

from django.contrib import admin

from email_confirm_la.models import EmailConfirmation


def resend_confirmation_email(modeladmin, request, queryset):
    for confirmation in queryset:
            confirmation.send()

resend_confirmation_email.short_description = 'Re-send selected %(verbose_name_plural)s'


class EmailConfirmationAdmin(admin.ModelAdmin):

    def show_content_type(self, obj):
        if not obj.content_object:
            return None
        return obj.content_object._meta.object_name
    show_content_type.short_description = 'Content type'

    actions = [resend_confirmation_email, ]
    list_display = ('show_content_type', 'content_object', 'email_field_name', 'email', 'send_at')
    list_display_links = list_display
    search_fields = ('email', )
    ordering = ('-id', )

admin.site.register(EmailConfirmation, EmailConfirmationAdmin)



# coding: utf-8

import datetime

from django.conf import settings
from django.contrib.contenttypes.models import ContentType
from django.core.mail import EmailMessage
from django.core.urlresolvers import reverse
from django.db import IntegrityError
from django.db import models
from django.template.loader import render_to_string
from django.utils import timezone
from django.utils.translation import ugettext_lazy as _

from email_confirm_la import signals
from email_confirm_la.conf import configs
from email_confirm_la.compat import GenericForeignKey
from email_confirm_la.exceptions import ExpiredError
from email_confirm_la.utils import generate_random_token


class EmailConfirmationManager(models.Manager):

    def verify_email_for_object(self, email, content_object, email_field_name='email'):
        """
        Create an email confirmation for `content_object` and send a confirmation mail.

        The email will be directly saved to `content_object.email_field_name` when `is_primary` and `skip_verify` both are true.
        """

        confirmation_key = generate_random_token([str(content_object.__class__.__name__), str(content_object.id), str(email_field_name), email, ])

        try:
            confirmation = EmailConfirmation()
            confirmation.content_object = content_object
            confirmation.email_field_name = email_field_name
            confirmation.email = email
            confirmation.confirmation_key = confirmation_key
            confirmation.save()
        except IntegrityError:
            confirmation = EmailConfirmation.objects.get_for_object(content_object, email_field_name)
            confirmation.email = email
            confirmation.confirmation_key = confirmation_key
            confirmation.save(update_fields=['email', 'confirmation_key'])

        confirmation.send()

        return confirmation

    def get_unverified_email_for_object(self, content_object, email_field_name='email'):
        try:
            confirmation = EmailConfirmation.objects.get_for_object(content_object, email_field_name)
        except EmailConfirmation.DoesNotExist:
            unverified_email = ''
        else:
            unverified_email = confirmation.email

        return unverified_email

    def get_for_object(self, content_object, email_field_name='email'):
        content_type = ContentType.objects.get_for_model(content_object)
        confirmation = EmailConfirmation.objects.get(content_type=content_type, object_id=content_object.id, email_field_name=email_field_name)

        return confirmation

    def get_queryset_for_object(self, content_object, email_field_name='email'):
        content_type = ContentType.objects.get_for_model(content_object)
        queryset = EmailConfirmation.objects.filter(content_type=content_type, object_id=content_object.id, email_field_name=email_field_name)

        return queryset

    def get_for_email(self, email, content_object_model, email_field_name='email'):
        content_type = ContentType.objects.get_for_model(content_object_model)
        confirmation = EmailConfirmation.objects.get(content_type=content_type, email_field_name=email_field_name, email=email)

        return confirmation


class EmailConfirmation(models.Model):
    """
    Once an email is confirmed, it will be delete from this table. In other words, there are only unconfirmed emails in the database.
    """

    ExpiredError = ExpiredError

    content_type = models.ForeignKey(ContentType)
    object_id = models.PositiveIntegerField()
    content_object = GenericForeignKey('content_type', 'object_id')
    email_field_name = models.CharField(verbose_name=_(u'Email field name'), max_length=32, default='email')
    email = models.EmailField(verbose_name=_(u'Email'), db_index=True)
    confirmation_key = models.CharField(verbose_name=_(u'Confirmation_key'), max_length=64, unique=True)
    send_at = models.DateTimeField(null=True, blank=True, db_index=True)

    objects = EmailConfirmationManager()

    class Meta:
        verbose_name = _(u'Email confirmation')
        verbose_name_plural = _(u'Email confirmation')
        unique_together = (('content_type', 'object_id', 'email_field_name'), )

    def __repr__(self):
        return '<EmailConfirmation {0}>'.format(self.email)

    def __str__(self):
        return 'Confirmation for {0}'.format(self.email)

    def __unicode__(self):
        return u'Confirmation for {0}'.format(self.email)

    def send(self, template_context=None):
        default_template_context = dict(configs.EMAIL_CONFIRM_LA_TEMPLATE_CONTEXT)
        default_template_context['email_confirmation'] = self

        if isinstance(template_context, dict):
            template_context = dict(default_template_context.items() + template_context.items())  # merge dictionaries
        else:
            template_context = default_template_context

        subject = render_to_string('email_confirm_la/email/email_confirmation_subject.txt', template_context)
        subject = ''.join(subject.splitlines()).strip()  # remove unnecessary line breaks
        body = render_to_string('email_confirm_la/email/email_confirmation_message.html', template_context)
        message = EmailMessage(subject, body, settings.DEFAULT_FROM_EMAIL, [self.email, ])
        message.content_subtype = 'html'
        message.send()

        self.send_at = timezone.now()
        self.save(update_fields=('send_at', ))

        signals.post_email_confirmation_send.send(
            sender=self.__class__,
            confirmation=self,
        )

    def get_confirmation_url(self, full=True):
        url_reverse_name = configs.EMAIL_CONFIRM_LA_CONFIRM_URL_REVERSE_NAME
        url = reverse(url_reverse_name, kwargs={'confirmation_key': self.confirmation_key})
        if full:
            confirmation_url = '{0}://{1}{2}'.format(configs.EMAIL_CONFIRM_LA_HTTP_PROTOCOL, configs.EMAIL_CONFIRM_LA_DOMAIN, url)
        else:
            confirmation_url = url

        return confirmation_url

    def confirm(self, ignore_expiration=False, save_to_content_object=True):
        if not ignore_expiration and self.is_expired:
            raise ExpiredError()

        if save_to_content_object:
            setattr(self.content_object, self.email_field_name, self.email)
            self.content_object.save(update_fields=(self.email_field_name, ))

        signals.post_email_confirmation_confirm.send(
            sender=self.__class__,
            confirmation=self,
            save_to_content_object=save_to_content_object,
        )

    def clean(self):
        """
        delete all confirmations for the same content_object and the same field
        """

        EmailConfirmation.objects.filter(content_type=self.content_type, object_id=self.object_id, email_field_name=self.email_field_name).delete()

    @property
    def is_expired(self):
        if not self.send_at:
            return False

        expiration_time = self.send_at + datetime.timedelta(seconds=configs.EMAIL_CONFIRM_LA_CONFIRM_EXPIRE_SEC)

        return expiration_time <= timezone.now()



# coding: utf-8

from django.shortcuts import render

from email_confirm_la.conf import configs
from email_confirm_la.models import EmailConfirmation


def confirm_email(request, confirmation_key):
    try:
        email_confirmation = EmailConfirmation.objects.get(confirmation_key=confirmation_key)
    except EmailConfirmation.DoesNotExist:
        return render(request, 'email_confirm_la/email_confirmation_fail.html')

    context = dict(configs.EMAIL_CONFIRM_LA_TEMPLATE_CONTEXT)
    context['email_confirmation'] = email_confirmation

    try:
        email_confirmation.confirm()
        email_confirmation.clean()
    except EmailConfirmation.ExpiredError:
        return render(request, 'email_confirm_la/email_confirmation_expiration.html', context)

    return render(request, 'email_confirm_la/email_confirmation_success.html', context)



# coding: utf-8

from django.contrib.auth.models import User
from django.core import mail
from django.core.management import call_command
from django.utils import timezone

from freezegun import freeze_time
from model_mommy import mommy

from .base import BaseTestCase
from email_confirm_la.models import EmailConfirmation
from test_app.models import YourModel


class ManagerTest(BaseTestCase):

    def setUp(self):
        self.user_obj = User.objects.create_user(username='kiko_mizuhara')
        self.user_obj_2 = User.objects.create_user(username='odyx')
        self.user_email = 'kiko.mizuhara@gmail.com'
        self.user_email_2 = 'kiko.mizuhara@yahoo.com'

        self.your_obj = YourModel.objects.create()
        self.your_customer_support_email = 'marvin@therestaurantattheendoftheuniverse.com'
        self.your_marketing_email = 'arthur@therestaurantattheendoftheuniverse.com'

    def test_verify_email_for_object_with_user_model(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        self.assertEqual(confirmation.content_object, self.user_obj)
        self.assertEqual(confirmation.email, self.user_email)
        self.assertEqual(confirmation.email_field_name, 'email')

        mail_obj = mail.outbox[0]

        self.assertIn(confirmation.confirmation_key, mail_obj.body)
        self.assertIn(self.user_email, mail_obj.body)

        confirmation.confirm()

        self.assertEqual(self.user_obj.email, self.user_email)

    def test_verify_email_for_object_with_some_model(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.your_customer_support_email,
            content_object=self.your_obj,
            email_field_name='customer_support_email'
        )

        self.assertEqual(confirmation.content_object, self.your_obj)
        self.assertEqual(confirmation.email, self.your_customer_support_email)
        self.assertEqual(confirmation.email_field_name, 'customer_support_email')

        mail_obj = mail.outbox[0]

        self.assertIn(confirmation.confirmation_key, mail_obj.body)
        self.assertIn(self.your_customer_support_email, mail_obj.body)

        confirmation.confirm()

        self.assertEqual(getattr(self.your_obj, 'customer_support_email'), self.your_customer_support_email)

    def test_request_the_same_email_by_two_users(self):
        the_same_email = self.user_email

        confirmation_1 = EmailConfirmation.objects.verify_email_for_object(
            email=the_same_email,
            content_object=self.user_obj,
        )
        confirmation_2 = EmailConfirmation.objects.verify_email_for_object(
            email=the_same_email,
            content_object=self.user_obj_2,
        )
        self.assertTrue(confirmation_1.email, the_same_email)
        self.assertTrue(confirmation_2.email, the_same_email)

        confirmation_2.confirm()

        self.assertEqual(self.user_obj_2.email, the_same_email)


class ModelTest(BaseTestCase):

    def setUp(self):
        self.user_obj = User.objects.create_user(username='kiko_mizuhara')
        self.user_email = 'kiko.mizuhara@gmail.com'
        self.user_email_2 = 'kiko.mizuhara@yahoo.com'

    def test_confirm(self):
        confirmation = EmailConfirmation.objects.verify_email_for_object(
            email=self.user_email,
            content_object=self.user_obj,
        )

        with freeze_time("3000-01-01"):
            with self.assertRaises(EmailConfirmation.ExpiredError):
                confirmation.confirm()


class CommandTest(BaseTestCase):

    def test_clear_expired_email_confirmations(self):
        mommy.make(
            'email_confirm_la.EmailConfirmation',
            _quantity=1,
            send_at=timezone.now()
        )

        self.assertEqual(EmailConfirmation.objects.all().count(), 1)

        with freeze_time("3000-01-01"):
            call_command('clear_expired_email_confirmations')

            self.assertEqual(EmailConfirmation.objects.all().count(), 0)



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'EmailConfirmation'
        db.create_table('email_confirm_la_emailconfirmation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('email_field_name', self.gf('django.db.models.fields.CharField')(max_length=32, default='email')),
            ('email', self.gf('django.db.models.fields.EmailField')(db_index=True, max_length=75)),
            ('confirmation_key', self.gf('django.db.models.fields.CharField')(max_length=64, unique=True)),
            ('send_at', self.gf('django.db.models.fields.DateTimeField')(blank=True, db_index=True, null=True)),
        ))
        db.send_create_signal('email_confirm_la', ['EmailConfirmation'])

        # Adding unique constraint on 'EmailConfirmation', fields ['content_type', 'object_id', 'email_field_name']
        db.create_unique('email_confirm_la_emailconfirmation', ['content_type_id', 'object_id', 'email_field_name'])


    def backwards(self, orm):
        # Removing unique constraint on 'EmailConfirmation', fields ['content_type', 'object_id', 'email_field_name']
        db.delete_unique('email_confirm_la_emailconfirmation', ['content_type_id', 'object_id', 'email_field_name'])

        # Deleting model 'EmailConfirmation'
        db.delete_table('email_confirm_la_emailconfirmation')


    models = {
        'contenttypes.contenttype': {
            'Meta': {'db_table': "'django_content_type'", 'ordering': "('name',)", 'object_name': 'ContentType', 'unique_together': "(('app_label', 'model'),)"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'email_confirm_la.emailconfirmation': {
            'Meta': {'object_name': 'EmailConfirmation', 'unique_together': "(('content_type', 'object_id', 'email_field_name'),)"},
            'confirmation_key': ('django.db.models.fields.CharField', [], {'max_length': '64', 'unique': 'True'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'email': ('django.db.models.fields.EmailField', [], {'db_index': 'True', 'max_length': '75'}),
            'email_field_name': ('django.db.models.fields.CharField', [], {'max_length': '32', 'default': "'email'"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'send_at': ('django.db.models.fields.DateTimeField', [], {'blank': 'True', 'db_index': 'True', 'null': 'True'})
        }
    }

    complete_apps = ['email_confirm_la']


# coding: utf-8

from django.dispatch import Signal


post_email_confirmation_send = Signal(providing_args=['confirmation', ])
post_email_confirmation_confirm = Signal(providing_args=['confirmation', 'save_to_content_object'])



# coding: utf-8

import hashlib
import random


def generate_random_token(factors=None, hash_func=hashlib.sha256):
    if factors is None:
        factors = []

    bits = factors + [str(random.SystemRandom().getrandbits(512)), ]

    return hash_func(''.join(bits).encode('utf-8')).hexdigest()



# coding: utf-8

from django.conf.urls import patterns, url


urlpatterns = patterns(
    'email_confirm_la.views',
    url(r'^key/(?P<confirmation_key>\w+)/$', 'confirm_email', name='confirm_email'),
)



# coding: utf-8

import django


__all__ = ['GenericForeignKey', ]


if django.VERSION >= (1, 7):
    from django.contrib.contenttypes.fields import GenericForeignKey
else:
    from django.contrib.contenttypes.generic import GenericForeignKey



# coding: utf-8

VERSION = (2, 1, 0)


def get_version():
    return '.'.join((str(number) for number in VERSION))


__version__ = get_version()

default_app_config = 'email_confirm_la.apps.ECLAAppConf'



# coding: utf-8

import datetime

from django.core.management.base import BaseCommand
from django.utils import timezone

from email_confirm_la.conf import configs
from email_confirm_la.models import EmailConfirmation


class Command(BaseCommand):

    def handle(self, **options):
        expiration_time = timezone.now() - datetime.timedelta(seconds=configs.EMAIL_CONFIRM_LA_CONFIRM_EXPIRE_SEC)
        EmailConfirmation.objects.filter(send_at__lt=expiration_time).delete()



# coding: utf-8

from django.conf import settings


class DefaultConfigs(object):

    EMAIL_CONFIRM_LA_HTTP_PROTOCOL = 'http'
    EMAIL_CONFIRM_LA_DOMAIN = 'example.com'
    EMAIL_CONFIRM_LA_CONFIRM_EXPIRE_SEC = 60 * 60 * 24 * 1  # 1 day
    EMAIL_CONFIRM_LA_CONFIRM_URL_REVERSE_NAME = 'email_confirm_la:confirm_email'
    EMAIL_CONFIRM_LA_TEMPLATE_CONTEXT = {}


class Configs(object):

    def __getattr__(self, name):
        default_setting = getattr(DefaultConfigs, name)
        setting = getattr(settings, name, default_setting)

        return setting


configs = Configs()



#!/usr/bin/env python

import os
import sys

from setuptools import find_packages, setup


if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist bdist_wheel upload')
    sys.exit()

version = __import__('email_confirm_la').get_version()

long_description = open('README.rst').read() + '\n\n' + open('CHANGES.rst').read()

license = open('LICENSE').read()

requirements_lines = [line.strip() for line in open('requirements.txt').readlines()]
install_requires = list(filter(None, requirements_lines))

setup(
    name='django-email-confirm-la',
    version=version,
    description='Django email confirmation for any Model and any Field.',
    long_description=long_description,
    keywords=('django', 'email', 'mail', 'confirm', 'confirmation', 'content type'),
    author='Vinta Chen',
    author_email='vinta.chen@gmail.com',
    url='https://github.com/vinta/django-email-confirm-la',
    license=license,
    install_requires=install_requires,
    include_package_data=True,
    packages=find_packages(exclude=['test_project.*', 'test_project']),
    test_suite='run_tests.main',
    zip_safe=False,
    classifiers=(
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Communications :: Email',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ),
)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-07-25 09:03
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailConfirmation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.PositiveIntegerField()),
                ('email_field_name', models.CharField(default='email', max_length=32, verbose_name='Email field name')),
                ('email', models.EmailField(db_index=True, max_length=254, verbose_name='Email')),
                ('confirmation_key', models.CharField(max_length=64, unique=True, verbose_name='Confirmation_key')),
                ('send_at', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
            ],
            options={
                'verbose_name': 'Email confirmation',
                'verbose_name_plural': 'Email confirmation',
            },
        ),
        migrations.AlterUniqueTogether(
            name='emailconfirmation',
            unique_together=set([('content_type', 'object_id', 'email_field_name')]),
        ),
    ]
